*$ CREATE USRHSC.FOR
*COPY USRHSC
*                                                                      *
*=== Usrhsc ===========================================================*
*                                                                      *
      SUBROUTINE USRHSC ( MREG  , REGNAM, MMAT, MMANAM, SFRHIO, SFRHOT )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 2005-2005      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     USer provided RHo (density) SCaling factors:                     *
*                                                                      *
*     Created on  31 august 2005   by    Alfredo Ferrari & Paola Sala  *
*                                             CERN, Infn - Milan       *
*                                                                      *
*     Last change on   28-sep-05   by    Alfredo Ferrari               *
*                                                                      *
*     Input variables:                                                 *
*           Mreg = region number                                       *
*         Regnam = region name                                         *
*           Mmat = master material name                                *
*         Mmanam = master material name                                *
*         Sfrhio = input dE/dx density scaling factor                  *
*         Sfrhot = input other processes density scaling factor        *
*                                                                      *
*     Output variables:                                                *
*           Mmat = master material name                                *
*         Mmanam = master material name                                *
*         Sfrhio = dE/dx density scaling factor                        *
*         Sfrhot = other processes density scaling factor              *
*                                                                      *
*     The user is supposed to change only Sfrhio and Sfrhot            *
*     Changing Mmat/Matnam is unsupported, it should work however it   *
*     is risky. In the case you like danger, change only Mmat OR       *
*     Matnam according to the new material assignment                  *
*                                                                      *
*----------------------------------------------------------------------*
*
      CHARACTER*8 REGNAM, MMANAM
*
      RETURN
*=== End of subroutine Usrhsc =========================================*
      END

